'''OpenGL extension EXT.render_snorm

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.render_snorm to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL ES 3.0 supports a variety of signed normalized texture and
	renderbuffer formats which are not color-renderable.
	
	This extension enables signed normalized texture and renderbuffer
	formats to be color-renderable.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/render_snorm.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.render_snorm import *
from OpenGL.raw.GLES2.EXT.render_snorm import _EXTENSION_NAME

def glInitRenderSnormEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_fragment_coverage_to_color'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_fragment_coverage_to_color',error_checker=_errors._error_checker)
GL_FRAGMENT_COVERAGE_COLOR_NV=_C('GL_FRAGMENT_COVERAGE_COLOR_NV',0x92DE)
GL_FRAGMENT_COVERAGE_TO_COLOR_NV=_C('GL_FRAGMENT_COVERAGE_TO_COLOR_NV',0x92DD)
@_f
@_p.types(None,_cs.GLuint)
def glFragmentCoverageColorNV(color):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_ANGLE_translated_shader_source'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_ANGLE_translated_shader_source',error_checker=_errors._error_checker)
GL_TRANSLATED_SHADER_SOURCE_LENGTH_ANGLE=_C('GL_TRANSLATED_SHADER_SOURCE_LENGTH_ANGLE',0x93A0)
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetTranslatedShaderSourceANGLE(shader,bufSize,length,source):pass
